==> Spec-Recorder%20Ver.1.01.zip: Spec-Recorder Ver.1.01/libhro.py <==
# -*- coding: utf-8 -*-
from PIL import Image
import time
import csv
import subprocess
import datetime
import sys
import os
import ConfigParser

def get_rgb(pos):#これは使わない
	global img
	img = img.convert("RGB")
	rgb = img.getpixel(pos)
	return(rgb)

def open_image(filename):#これはつかわない、つかえない
	#global img
	img = Image.open(filename)
	return
	
def get_strength(pos):#これを使うととても遅いので使わない
	rgb = get_rgb(pos)
	if rgb[0] == rgb[1] and rgb[1] == rgb[2]:
		strength = rgb[0]
	else:
		print "Error this is color image"
	return(strength)

def make_list(img):
	strength_list = []
	img = img.convert("RGB")
	for cntx in range(2394):   #58-2451 #2393
		print "   " + str(cntx)
		listy = []
		for cnty in range(70):    #184-115
			#print cnty
			pos = (cntx + 58,cnty + 115)#115
			rgb = img.getpixel(pos)
			if rgb[0] == rgb[1] and rgb[1] == rgb[2]:
				strength = rgb[0]
			else:
				print "Error this is color image"
			listy.append(strength)
			#print listy
			time.sleep(0.0001)
		#print listy
		strength_list.append(listy)
	return(strength_list)
	
def write_csv(strength_list, filetime):
	writecsv = csv.writer(file(filetime + ".csv", 'w'), lineterminator='\n') 
	#len_list = len(strength_list)
	for cnt in range(2394):
		writecsv.writerow(strength_list[cnt][:])
	return()
	
def read_csv(strength_list, filetime):
	#readcsv = csv.reader(file(filetime + ".csv", 'r'), lineterminator='\n') 
	"""
	for cnt in range(2394):
		#readcsv.readrow(strength_list[cnt][:])
		strength_list.append(readcsv.readlines())
		"""
	for row in csv.reader(open(filetime + ".csv", 'rb')):
		strength_list.append(row)
	return(strength_list)
		
def get_strength_average(strength_list,cntx):
	strength_average = 0
	strength_sum = 0
	for average_cnt in range(70): 
		strength_sum = strength_sum + int(strength_list[cntx][average_cnt])
	strength_average = strength_sum / 70
	#print "                    " + str(strength_sum / 40)
	return(strength_average)
	
def analyze(strength_list):
	echo_list = []
	echo_time = []
	freq_list = []
	whole_strength_average = 0
	ave_sum = 0
	for cnt in range(2394):
		ave_sum = ave_sum + get_strength_average(strength_list,cnt)
	whole_strength_average = ave_sum / 2394
	for cntx in range(2394):
		echo_freq = 0
		print cntx + 58
		echo1 = False
		echo2 = False
		echo3 = False
		echo = False
		#echo_list.append([echo, echo_freq])
		#echo_list.append([])
		#echo_list[cntx].append([0])
		#echo_list[cntx][].append([0])
		for cnty in range(15,55):
			if int(strength_list[cntx][cnty]) > get_strength_average(strength_list,cntx) + 20:
				strength_sum = 0
				if int(strength_list[cntx][cnty]) > whole_strength_average + 30:
					#その時刻の強さの平均よりエコーが大きい
					print "echo!"
					echo1 = True
					echo = 1
					if echo_freq != 0:
						if int(strength_list[cntx][echo_freq]) < int(strength_list[cntx][cnty]):
							echo_freq = cnty
							#print echo_freq
							#前のエコーより今のエコーが大きかったらecho_freqを書き換える
							#echo_list[cntx][1] = cnty#echo_listにy座標を加える
					else:
						echo_freq = cnty
						#print len(echo_list[cntx])
						#echo_list[cntx][1] = cnty#echo_listにy座標を加える
			
			else:
				if cntx > 2:
					before_sum2 = int(strength_list[cntx][cnty]) + int(strength_list[cntx - 1][cnty])
					if before_sum2 / 2 > int(strength_list[cntx -2][cnty]) + 40:
						#if int(strength_list[cntx - 1][cnty]) + 40 < int(strength_list[cntx][cnty]):
						#1つ前、2つ前の平均と比べる
						average_cnt = 0
						"""
						for average_cnt in range(15,55):
							strength_sum = strength_sum + int(strength_list[cntx][average_cnt])
						strength_average = strength_sum / 40
						print "              " + str(strength_sum / 40)
						"""
						#print str(strength_list[cntx][cnty])+ "   " + str(get_strength_average(strength_list,cntx))
						if int(strength_list[cntx][cnty]) > get_strength_average(strength_list,cntx) + 40:
							#その時刻の強さの平均よりエコーが大きい
							print "echo2!"
							echo = 2
							#echo_list[cntx][0] = cntx#echo_listにx座標を加える
							if echo_freq != 0:
								if int(strength_list[cntx][echo_freq]) + 50 < int(strength_list[cntx][cnty]):
									echo_freq = cnty
									#前のエコーより今のエコーが大きかったらecho_freqを書き換える
									echo2 = True
									
									#echo_list[cntx][1] = cnty#echo_listにy座標を加える
							else:
								echo_freq = cnty
								#echo_list[cntx][1] = cnty#echo_listにy座標を加える
			"""					
		if len(echo_time) > 3:
			if echo_list[cntx - 1][1] == 500:#一つ前のXもエコーであるとき
				if echo_list[cntx - 2][1] == 500:
					print 4444444444444444444444444444
					if abs(int(strength_list[cntx][cnty]) - int(strength_list[cntx - 1][cnty])) < 100:
						echo3 =True
						echo = 3
						print 33333333333333333333333333333333333333333
						#if echo1 == True or echo2 == True:
							"""
					
		if echo == 1 or echo == 2:#echo_timeへの記録
			if len(echo_time) != 0:
				if echo_time[len(echo_time) - 1] != cntx - 1 + 58:
					echo_time.append(cntx + 58)
					#print 11111111111111111111111111111111111
			else:
				echo_time.append(cntx + 58)
				#print 22222222222222222222222222222222
				
		if echo_freq == 0:
			freq_list.append(echo_freq + 500)
			echo_list.append([echo, echo_freq + 500])
		else:
			freq_list.append(echo_freq + 115)
			echo_list.append([echo, echo_freq + 115])
 		
 		#echo_list.append([echo, echo_freq])
 		
			#if if1 == True:
			#	for average_cnt in range(80,221):
			#		strength_sum = strength_sum + strength_list[cntx][average_cnt]
			#	strength_average = strength_sum / 40
			#	if strength_list[cntx][cnty] + 40 > strength_average:
			#		if2 = True
					#その時刻の強さの平均よりエコーが大きい
			#	else:
			#		if2 = False
		
	print echo_time
	#print freq_list
	print echo_list
	return(echo_time)

==> Spec-Recorder%20Ver.1.12.zip: Spec-Recorder Ver.1.12/libhro.py <==
# -*- coding: utf-8 -*-
from PIL import Image
import time
import csv
import subprocess
import datetime
import sys
import os
import ConfigParser

def get_rgb(pos):#これは使わない
	global img
	img = img.convert("RGB")
	rgb = img.getpixel(pos)
	return(rgb)

def open_image(filename):#これはつかわない、つかえない
	#global img
	img = Image.open(filename)
	return
	
def get_strength(pos):#これを使うととても遅いので使わない
	rgb = get_rgb(pos)
	if rgb[0] == rgb[1] and rgb[1] == rgb[2]:
		strength = rgb[0]
	else:
		print "Error this is color image"
	return(strength)

def make_list(img):
	strength_list = []
	img = img.convert("RGB")
	for cntx in range(2394):   #58-2451 #2393
		print "   " + str(cntx)
		listy = []
		for cnty in range(70):    #184-115
			#print cnty
			pos = (cntx + 58,cnty + 115)#115
			rgb = img.getpixel(pos)
			if rgb[0] == rgb[1] and rgb[1] == rgb[2]:
				strength = rgb[0]
			else:
				print "Error this is color image"
			listy.append(strength)
			#print listy
			time.sleep(0.0001)
		#print listy
		strength_list.append(listy)
	return(strength_list)
	
def write_csv(strength_list, filetime):
	writecsv = csv.writer(file("./CSV/" + filetime + ".csv", 'w'), lineterminator='\n') 
	#len_list = len(strength_list)
	for cnt in range(2394):
		writecsv.writerow(strength_list[cnt][:])
	return()
	
def read_csv(strength_list, filetime):
	#readcsv = csv.reader(file(filetime + ".csv", 'r'), lineterminator='\n') 
	"""
	for cnt in range(2394):
		#readcsv.readrow(strength_list[cnt][:])
		strength_list.append(readcsv.readlines())
		"""
	for row in csv.reader(open("./CSV/" + filetime + ".csv", 'rb')):
		strength_list.append(row)
	return(strength_list)
		
def get_strength_average(strength_list,cntx):
	strength_average = 0
	strength_sum = 0
	for average_cnt in range(70): 
		strength_sum = strength_sum + int(strength_list[cntx][average_cnt])
	strength_average = strength_sum / 70
	#print "                    " + str(strength_sum / 40)
	return(strength_average)
	
def analyze(strength_list):
	echo_list = []
	echo_time = []
	freq_list = []
	long_list = []
	long_start = 0
	whole_strength_average = 0
	ave_sum = 0
	for cnt in range(2394):
		ave_sum = ave_sum + get_strength_average(strength_list,cnt)
	whole_strength_average = ave_sum / 2394
	for cntx in range(2394):
		echo_freq = 0
		print cntx + 58
		echo1 = False
		echo2 = False
		echo3 = False
		echo = False
		#echo_list.append([echo, echo_freq])
		#echo_list.append([])
		#echo_list[cntx].append([0])
		#echo_list[cntx][].append([0])
		for cnty in range(15,55):
			if int(strength_list[cntx][cnty]) > get_strength_average(strength_list,cntx) + 20:
				strength_sum = 0
				if int(strength_list[cntx][cnty]) > whole_strength_average + 30:
					#その時刻の強さの平均よりエコーが大きい
					print "echo!"
					echo1 = True
					echo = 1
					if echo_freq != 0:
						if int(strength_list[cntx][echo_freq]) < int(strength_list[cntx][cnty]):
							echo_freq = cnty
							#print echo_freq
							#前のエコーより今のエコーが大きかったらecho_freqを書き換える
							#echo_list[cntx][1] = cnty#echo_listにy座標を加える
					else:
						echo_freq = cnty
						#print len(echo_list[cntx])
						#echo_list[cntx][1] = cnty#echo_listにy座標を加える
			
			else:
				if cntx > 2:
					before_sum2 = int(strength_list[cntx][cnty]) + int(strength_list[cntx - 1][cnty])
					if before_sum2 / 2 > int(strength_list[cntx -2][cnty]) + 40:
						#if int(strength_list[cntx - 1][cnty]) + 40 < int(strength_list[cntx][cnty]):
						#1つ前、2つ前の平均と比べる
						average_cnt = 0
						"""
						for average_cnt in range(15,55):
							strength_sum = strength_sum + int(strength_list[cntx][average_cnt])
						strength_average = strength_sum / 40
						print "              " + str(strength_sum / 40)
						"""
						#print str(strength_list[cntx][cnty])+ "   " + str(get_strength_average(strength_list,cntx))
						if int(strength_list[cntx][cnty]) > get_strength_average(strength_list,cntx) + 40:
							#その時刻の強さの平均よりエコーが大きい
							print "echo2!"
							echo = 2
							#echo_list[cntx][0] = cntx#echo_listにx座標を加える
							if echo_freq != 0:
								if int(strength_list[cntx][echo_freq]) + 50 < int(strength_list[cntx][cnty]):
									echo_freq = cnty
									#前のエコーより今のエコーが大きかったらecho_freqを書き換える
									echo2 = True
									
									#echo_list[cntx][1] = cnty#echo_listにy座標を加える
							else:
								echo_freq = cnty
								#echo_list[cntx][1] = cnty#echo_listにy座標を加える
			"""					
		if len(echo_time) > 3:
			if echo_list[cntx - 1][1] == 500:#一つ前のXもエコーであるとき
				if echo_list[cntx - 2][1] == 500:
					print 4444444444444444444444444444
					if abs(int(strength_list[cntx][cnty]) - int(strength_list[cntx - 1][cnty])) < 100:
						echo3 =True
						echo = 3
						print 33333333333333333333333333333333333333333
						#if echo1 == True or echo2 == True:
							"""
					
		if echo == 1 or echo == 2:#echo_timeへの記録
			if len(echo_list) != 0:
				if echo_list[len(echo_list) - 1][2] != cntx - 1:
					echo_time.append(cntx + 58)
					echo_list.append([echo, echo_freq + 115, cntx])
				else:
					echo = 3
					echo_list.append([echo, echo_freq + 115, cntx])
			else:
				echo_time.append(cntx + 58)
				echo_list.append([echo, echo_freq + 115, cntx])
				#print 22222222222222222222222222222222
		
		"""		
		if echo_freq == 0:
			freq_list.append(echo_freq + 500)
			echo_list.append([echo, echo_freq + 500])
		else:
			freq_list.append(echo_freq + 115)
			echo_list.append([echo, echo_freq + 115])
 		"""
 		#echo_list.append([echo, echo_freq])
 		
			#if if1 == True:
			#	for average_cnt in range(80,221):
			#		strength_sum = strength_sum + strength_list[cntx][average_cnt]
			#	strength_average = strength_sum / 40
			#	if strength_list[cntx][cnty] + 40 > strength_average:
			#		if2 = True
					#その時刻の強さの平均よりエコーが大きい
			#	else:
			#		if2 = False
			
	#エコーじゃないものを排除する（できるかなぁ）
	long_list = []
	for cnt in range(len(echo_list)):
		if echo_list[cnt][0] == 3 and echo_list[cnt -1][0] != 3:
			pass
		
	print echo_time
	#print long_list
	#print freq_list
	print echo_list
	return(echo_time)
